@@ -152,6 +152,13 @@ class FrontDoorConfig:
             except AttributeError:
                 pass
 
+    def __iter__(self):
+        for k, v  in {k: getattr(self, k) for k in self.defaults.keys()}.items():
+            yield k, v
+
+    def __len__(self):
+        return len(self.defaults)
+
 
 class DjangoSettings(FrontDoorConfig):
     def _get(self, key):
