@@ -1,15 +1,14 @@
 from django import forms
 from django.utils.translation import gettext as _
 
-# class FrontDoorLogLevel(forms.CharField):
 from front_door.conf import LOG_NONE, LOG_FAIL, LOG_PASS, LOG_RULE_FAIL, LOG_RULE_PASS, LOG_ALL
 
 
 class FrontDoorLogLevel(forms.ChoiceField):
     def __init__(self, **kwargs):
         choices = ([LOG_NONE, _("None")],
-                   [LOG_FAIL, "Log Access Failures"],
-                   [LOG_PASS, "Log Access"],
+                   [LOG_FAIL, "Log Access Deny"],
+                   [LOG_PASS, "Log Access Allow"],
                    [LOG_RULE_FAIL, "Log Rule Failure"],
                    [LOG_RULE_PASS, "Log Rule Pass"],
                    [LOG_ALL, "Log Everything"],
